@@ -1,7 +1,7 @@
 package Data::Transmute;
 
 our $DATE = '2015-05-05'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -115,22 +115,12 @@ Data::Transmute - Transmute (transform) data structure using rules data
 
 =head1 VERSION
 
-This document describes version 0.01 of Data::Transmute (from Perl distribution Data-Transmute), released on 2015-05-05.
+This document describes version 0.02 of Data::Transmute (from Perl distribution Data-Transmute), released on 2015-05-05.
 
 =head1 SYNOPSIS
 
  use Data::Transmute qw(transmute_array transmute_hash);
 
- my %hash = (
-     foo => 1,
-
-     one => 2,
-     two => 3,
-
-     x_apple => 4,
-     x_mango => 5,
- );
-
  transmute_hash(
      data => \%hash,
      rules => [
@@ -160,17 +150,6 @@ This document describes version 0.01 of Data::Transmute (from Perl distribution
      ],
  );
 
- # %hash will become:
- # (
- #     baz => 1,
- #
- #     1 => 2,
- #     2 => 3,
- #
- #     apple => 4,
- #     mango => 5,
- # )
-
 =head1 DESCRIPTION
 
 B<STATUS: EARLY DEVELOPMENT, SOME FEATURES MIGHT BE MISSING>
